@@ -48,6 +48,15 @@
 #define O_BINARY 0
 #endif
 
+#ifdef G_OS_WIN32
+/* The gmtime_r() definition in pthreads-win32's pthread.h doesn't
+ * guard against gmtime() returning NULL.
+ */
+#undef gmtime_r
+/* The gmtime() in Microsoft's C library is MT-safe */
+#define gmtime_r(tp,tmp) (gmtime(tp)?(*(tmp)=*gmtime(tp),(tmp)):0)
+#endif
+
 /* Private part of the CalBackendGroupwise structure */
 struct _ECalBackendGroupwisePrivate {
 	/* A mutex to control access to the private structure */
@@ -238,7 +247,7 @@ get_deltas (gpointer handle)
 	GSList *cache_keys = NULL;
 	GPtrArray *uid_array = g_ptr_array_new ();
 	char *time_string = NULL;
-	char t_str [100]; 
+	char t_str [26]; 
 	const char *serv_time;
 	static GStaticMutex connecting = G_STATIC_MUTEX_INIT;
 	const char *time_interval_string;
@@ -252,7 +261,7 @@ get_deltas (gpointer handle)
 	icaltimetype temp;
 	gboolean done = FALSE;
 	int cursor = 0;
-	struct tm *tm;
+	struct tm tm;
 	time_t current_time;
 	gboolean needs_to_get = FALSE;
 
@@ -280,16 +289,16 @@ get_deltas (gpointer handle)
 			g_warning ("\n\a Could not get the correct time stamp. \n\a");
 			temp = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
 			current_time = icaltime_as_timet_with_zone (temp, icaltimezone_get_utc_timezone ());
-			tm = gmtime (&current_time);
-			strftime (t_str, 100, "%Y-%m-%dT%H:%M:%SZ", tm);
+			gmtime_r (&current_time, &tm);
+			strftime (t_str, 26, "%Y-%m-%dT%H:%M:%SZ", &tm);
 		}
 	} else {
 		/* FIXME: When time-stamp is crashed, getting changes from current time */
 		g_warning ("\n\a Could not get the correct time stamp. \n\a");
 		temp = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
 		current_time = icaltime_as_timet_with_zone (temp, icaltimezone_get_utc_timezone ());
-		tm = gmtime (&current_time);
-		strftime (t_str, 100, "%Y-%m-%dT%H:%M:%SZ", tm);
+		gmtime_r (&current_time, &tm);
+		strftime (t_str, 26, "%Y-%m-%dT%H:%M:%SZ", &tm);
 	}
 	time_string = g_strdup (t_str);
 
@@ -363,7 +372,7 @@ get_deltas (gpointer handle)
 
 	temp = icaltime_from_string (time_string);
 	current_time = icaltime_as_timet_with_zone (temp, icaltimezone_get_utc_timezone ());
-	tm = gmtime (&current_time);
+	gmtime_r (&current_time, &tm);
 
 	time_interval = (CACHE_REFRESH_INTERVAL / 60000);
 	time_interval_string = g_getenv ("GETQM_TIME_INTERVAL");
@@ -371,12 +380,12 @@ get_deltas (gpointer handle)
 		time_interval = g_ascii_strtod (time_interval_string, NULL);
 	} 
 	if (attempts) {
-		tm->tm_min += (time_interval * g_ascii_strtod (attempts, NULL));
+		tm.tm_min += (time_interval * g_ascii_strtod (attempts, NULL));
 		e_cal_backend_cache_put_key_value (cache, key, NULL);
 	} else {
-		tm->tm_min += time_interval;
+		tm.tm_min += time_interval;
 	}
-	strftime (t_str, 100, "%Y-%m-%dT%H:%M:%SZ", tm);
+	strftime (t_str, 100, "%Y-%m-%dT%H:%M:%SZ", &tm);
 	time_string = g_strdup (t_str);
 
 	e_cal_backend_cache_put_server_utc_time (cache, time_string);
@@ -1527,6 +1536,7 @@ e_cal_backend_groupwise_compute_changes_foreach_key (const char *key, const char
 		be_data->deletes = g_list_prepend (be_data->deletes, e_cal_component_get_as_string (comp));
 
 		e_xmlhash_remove (be_data->ehash, key);
+		g_object_unref (comp);
  	}
 }
 
@@ -1801,7 +1811,7 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 	ECalComponent *comp, *cache_comp = NULL;
 	EGwConnectionStatus status;
 	EGwItem *item, *cache_item;
-	const char *uid = NULL;
+	const char *uid = NULL, *rid = NULL;
 
 	*old_object = NULL;
 	cbgw = E_CAL_BACKEND_GROUPWISE (backend);
@@ -1814,22 +1824,22 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 		in_offline (cbgw);
 		return GNOME_Evolution_Calendar_RepositoryOffline;
 	}
-
+	
 	/* check the component for validity */
 	icalcomp = icalparser_parse_string (calobj);
 	if (!icalcomp)
 		return GNOME_Evolution_Calendar_InvalidObject;
-
 	comp = e_cal_component_new ();
 	e_cal_component_set_icalcomponent (comp, icalcomp);
 	e_cal_component_get_uid (comp, &uid);
+	rid = e_cal_component_get_recurid_as_string (comp);
 
 	/* check if the object exists */
 	switch (priv->mode) {
 	case CAL_MODE_ANY :
 	case CAL_MODE_REMOTE :
 		/* when online, send the item to the server */
-		cache_comp = e_cal_backend_cache_get_component (priv->cache, uid, NULL);
+		cache_comp = e_cal_backend_cache_get_component (priv->cache, uid, rid);
 		if (!cache_comp) {
 			g_message ("CRITICAL : Could not find the object in cache");
 			return GNOME_Evolution_Calendar_ObjectNotFound;
@@ -1843,9 +1853,8 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 
 			if (mod == CALOBJ_MOD_ALL && e_cal_component_is_instance (comp)) {
 				recur_key = uid;
-			} else {
-				id = e_gw_item_get_id (item);
-			}
+			} 
+			id = e_gw_item_get_id (item);
 
 			status = e_gw_connection_delegate_request (priv->cnc, item, id, NULL, NULL, recur_key); 
 		
@@ -2034,7 +2043,7 @@ e_cal_backend_groupwise_remove_object (ECalBackendSync *backend, EDataCal *cal,
 
 					e_cal_backend_cache_remove_component (priv->cache, id->uid, 
 							id->rid);
-					if (!g_str_equal (id->rid, rid))
+					if (!id->rid || !g_str_equal (id->rid, rid))
 						e_cal_backend_notify_object_removed (E_CAL_BACKEND (cbgw), id, e_cal_component_get_as_string (comp), NULL);
 					e_cal_component_free_id (id);
 					
