@@ -2,7 +2,7 @@
   FILE: icalvcal.c
   CREATOR: eric 25 May 00
   
-  $Id: icalvcal.c,v 1.7 2004/02/04 21:07:47 jpr Exp $
+  $Id: icalvcal.c,v 1.9 2005/09/15 12:02:33 tml Exp $
 
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -655,6 +655,10 @@ static int get_alarm_properties (icalcomponent *comp, VObject *object,
 	    url = icalattach_get_url (attach);
 
 	    /* Check for Gnome Calendar, which will just save a pathname. */
+	    /* FIXME: This is broken on Win32. No idea whether this code
+	     * ever is invoked in the context of Evolution, though.
+	     * --tml@novell.com
+	     */
 	    if (url && url[0] == '/') {
 		int len;
 		char *new_url;
@@ -1009,7 +1013,7 @@ static char* rrule_parse_weekly_days (char *s,
 	return NULL;
 
     for (i = 0; i < ICAL_BY_DAY_SIZE; i++) {
-	char *e;
+	char *e = s;
 	int found_day, day;
 
 	found_day = -1;
@@ -1103,7 +1107,7 @@ static char* rrule_parse_monthly_positions (char *s,
     int occurrences[ICAL_BY_DAY_SIZE];
     int found_weekdays[7] = { 0 };
     int i, num_positions, elems, month_position, day;
-    int num_weekdays, only_weekday;
+    int num_weekdays, only_weekday = 0;
     char *e;
 
     /* If we've already found an error, just return. */
@@ -1143,7 +1147,7 @@ static char* rrule_parse_monthly_positions (char *s,
 
     /* Now read the weekdays in. */
     for (;;) {
-	char *e;
+	char *e = s;
 	int found_day, day;
 
 	found_day = -1;
@@ -1312,10 +1316,7 @@ static char* rrule_parse_yearly_days (char *s,
 void* rule_prop(int icaltype, VObject *object, icalcomponent *comp,
 		icalvcal_defaults *defaults)
 {
-    icalproperty_kind kind = (icalproperty_kind)icaltype;
     icalproperty *prop = NULL;
-    icalvalue *value;
-    icalvalue_kind value_kind;
     char *s, *p, *error_message = NULL;
     const char *property_name;
     int free_string;
@@ -1394,7 +1395,7 @@ void* dc_prop(int icaltype, VObject *object, icalcomponent *comp,
     icalproperty *prop; 
     icalvalue *value;
     icalvalue_kind value_kind;
-    char *s,*t=0;
+    char *s;
     int free_string;
 
 
