@@ -3,7 +3,7 @@
  * Copyright 2002 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -11,7 +11,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -25,8 +25,8 @@
 #include <ctype.h>
 #include <string.h>
 
-#include "camel-sasl-ntlm.h"
 #include "camel-i18n.h"
+#include "camel-sasl-ntlm.h"
 
 CamelServiceAuthType camel_sasl_ntlm_authtype = {
 	N_("NTLM / SPA"),
@@ -524,13 +524,12 @@ static guint32 Spbox[8][64] = {
 	l ^= Spbox[3][(work >> 16) & 0x3f];\
 	l ^= Spbox[1][(work >> 24) & 0x3f];\
 }
+
 /* Encrypt or decrypt a block of data in ECB mode */
 static void
-des(ks,block)
-guint32 ks[16][2];	/* Key schedule */
-unsigned char block[8];		/* Data block */
+des (guint32 ks[16][2], unsigned char block[8])
 {
-	guint32 left,right,work;
+	guint32 left, right, work;
 	
 	/* Read input block and place in left/right in big-endian order */
 	left = ((guint32)block[0] << 24)
@@ -663,10 +662,7 @@ static int bytebit[] = {
  * depending on the value of "decrypt"
  */
 static void
-deskey(k,key,decrypt)
-DES_KS k;			/* Key schedule array */
-unsigned char *key;		/* 64 bits (will use only 56) */
-int decrypt;			/* 0 = encrypt, 1 = decrypt */
+deskey (DES_KS k, unsigned char *key, int decrypt)
 {
 	unsigned char pc1m[56];		/* place to modify pc1 into */
 	unsigned char pcr[56];		/* place to rotate pc1 into */
