@@ -49,6 +49,7 @@
 #include <e-gw-connection.h>
 #include <e-gw-item.h>
 
+#include <libsoup/soup-misc.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -59,6 +60,7 @@
 #define JUNK_FOLDER "Junk Mail"
 #define READ_CURSOR_MAX_IDS 500
 
+#define GROUPWISE_BULK_DELETE_LIMIT 100
 static CamelOfflineFolderClass *parent_class = NULL;
 
 struct _CamelGroupwiseFolderPrivate {
@@ -81,15 +83,15 @@ static void groupwise_transfer_messages_to (CamelFolder *source,
 static int gw_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args);
 void convert_to_calendar (EGwItem *item, char **str, int *len);
 static void convert_to_task (EGwItem *item, char **str, int *len);
-static void gw_update_all_items ( CamelFolder *folder, GSList *item_list, CamelException *ex);
+static void gw_update_all_items ( CamelFolder *folder, GList *item_list, CamelException *ex);
 static void groupwise_populate_details_from_item (CamelMimeMessage *msg, EGwItem *item);
 static void groupwise_populate_msg_body_from_item (EGwConnection *cnc, CamelMultipart *multipart, EGwItem *item, char *body);
 static void groupwise_msg_set_recipient_list (CamelMimeMessage *msg, EGwItem *item);
-static void gw_update_cache ( CamelFolder *folder, GList *item_list,CamelException *ex);
+static void gw_update_cache ( CamelFolder *folder, GList *item_list, CamelException *ex, gboolean uid_flag);
 static CamelMimeMessage *groupwise_folder_item_to_msg ( CamelFolder *folder, EGwItem *item, CamelException *ex );
 
 
-#define d(x) x
+#define d(x) 
 
 static CamelMimeMessage *
 groupwise_folder_get_message( CamelFolder *folder,
@@ -116,6 +118,7 @@ groupwise_folder_get_message( CamelFolder *folder,
 				_("Cannot get message: %s\n  %s"), uid, _("No such message"));
 		return NULL;
 	}
+	
 	cache_stream  = camel_data_cache_get (gw_folder->cache, "cache", uid, ex);
 	stream = camel_stream_mem_new ();
 	if (cache_stream) {
@@ -498,7 +501,8 @@ update_junk_list (CamelStore *store, CamelMessageInfo *info, int flag)
 		goto error;
 
 	email = g_strsplit_set (from, "<>", -1);
-	if (!email[1])
+
+	if (!email || !email[1])
 		goto error;
 
 	if (flag == ADD_JUNK_ENTRY)
@@ -586,13 +590,18 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
 	CamelMessageInfo *info = NULL;
 	CamelGroupwiseMessageInfo *gw_info;
-	GList *read_items = NULL, *deleted_items = NULL;
+	GList *read_items = NULL;
 	flags_diff_t diff;
 	const char *container_id;
 	EGwConnectionStatus status;
 	EGwConnection *cnc;
 	int count, i;
 
+	GList *deleted_items, *deleted_head = NULL;
+
+	deleted_items = NULL;
+
+
 	if (((CamelOfflineStore *) gw_store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL || 
 	    ((CamelService *)gw_store)->status == CAMEL_SERVICE_DISCONNECTED) {
 		groupwise_sync_summary (folder, ex);
@@ -624,6 +633,7 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 
 		if ((flags & CAMEL_MESSAGE_JUNK) && !(flags & CAMEL_GW_MESSAGE_JUNK)) /*marked a message junk*/
 			move_to_junk (folder, info, ex);
+
 		else if ((flags & CAMEL_MESSAGE_JUNK) && (flags & CAMEL_GW_MESSAGE_JUNK)) /*message was marked as junk, now unjunk*/ 
 			move_to_mailbox (folder, info, ex);
 
@@ -632,30 +642,65 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 			diff.changed &= folder->permanent_flags;
 
 			/* weed out flag changes that we can't sync to the server */
-			if (!diff.changed)
+			if (!diff.changed) {
 				camel_message_info_free(info);
-			else {
+				continue;
+			} else {
 				const char *uid = camel_message_info_uid (info);
 				if (diff.changed & CAMEL_MESSAGE_SEEN)
 					read_items = g_list_append (read_items, (char *)uid);
 				if (diff.changed & CAMEL_MESSAGE_DELETED) {
-					CAMEL_SERVICE_LOCK (gw_store, connect_lock);
-					status = e_gw_connection_remove_item (cnc, container_id, uid);
-					if (status == E_GW_CONNECTION_STATUS_OK) {
-						CAMEL_GROUPWISE_FOLDER_LOCK (folder, cache_lock);
-						camel_folder_summary_remove (folder->summary, info);
-						camel_data_cache_remove(gw_folder->cache, "cache", uid, ex);
-						CAMEL_GROUPWISE_FOLDER_UNLOCK (folder, cache_lock);
-						i--; count--;
+					if (deleted_items)
+						deleted_items = g_list_prepend (deleted_items, (char *)camel_message_info_uid (info));
+					else {
+						g_list_free (deleted_head);
+						deleted_head = NULL;
+						deleted_head = deleted_items = g_list_prepend (deleted_items, (char *)camel_message_info_uid (info));
+					}
+
+					if (g_list_length (deleted_items) == GROUPWISE_BULK_DELETE_LIMIT ) {
+						CAMEL_SERVICE_LOCK (gw_store, connect_lock);
+						status = e_gw_connection_remove_items (cnc, container_id, deleted_items);
+						CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+						if (status == E_GW_CONNECTION_STATUS_OK) {
+							char *uid;
+							while (deleted_items) {
+								uid = (char *)deleted_items->data;
+								CAMEL_GROUPWISE_FOLDER_LOCK (folder, cache_lock);
+								camel_folder_summary_remove_uid (folder->summary, uid);
+								camel_data_cache_remove(gw_folder->cache, "cache", uid, ex);
+								CAMEL_GROUPWISE_FOLDER_UNLOCK (folder, cache_lock);
+								deleted_items = g_list_next (deleted_items);
+								count -= GROUPWISE_BULK_DELETE_LIMIT;
+								i -= GROUPWISE_BULK_DELETE_LIMIT;
+							}
+						}
 					}
-					CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
 				}
 			}
 		}
 		camel_message_info_free (info);
-		info = NULL;
 	}
 	CAMEL_GROUPWISE_FOLDER_UNLOCK (folder, cache_lock);
+	if (deleted_items) {
+		CAMEL_SERVICE_LOCK (gw_store, connect_lock);
+		status = e_gw_connection_remove_items (cnc, container_id, deleted_items);
+		CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+		if (status == E_GW_CONNECTION_STATUS_OK) {
+			char *uid;
+			while (deleted_items) {
+				uid = (char *)deleted_items->data;
+				CAMEL_GROUPWISE_FOLDER_LOCK (folder, cache_lock);
+				camel_folder_summary_remove_uid (folder->summary, uid);
+				camel_data_cache_remove(gw_folder->cache, "cache", uid, ex);
+				CAMEL_GROUPWISE_FOLDER_UNLOCK (folder, cache_lock);
+				deleted_items = g_list_next (deleted_items);
+				count -= GROUPWISE_BULK_DELETE_LIMIT;
+				i -= GROUPWISE_BULK_DELETE_LIMIT;
+			}
+		}
+		g_list_free (deleted_head);
+	}
 
 	if (read_items && g_list_length (read_items)) {
 		CAMEL_SERVICE_LOCK (gw_store, connect_lock);
@@ -761,7 +806,7 @@ update_update (CamelSession *session, CamelSessionThreadMsg *msg)
 	EGwConnectionStatus status;
 	CamelException *ex = NULL;
 
-	GList *item_list;
+	GList *item_list, *items_full_list = NULL, *last_element = NULL;
 	int cursor = 0;
 	const char *position = E_GW_CURSOR_POSITION_END;
 	gboolean done;
@@ -787,16 +832,43 @@ update_update (CamelSession *session, CamelSessionThreadMsg *msg)
 		if (!item_list  || g_list_length (item_list) == 0)
 			done = TRUE;
 		else {
-			for (;item_list; item_list = g_list_next (item_list)) {
-				m->slist = g_slist_prepend (m->slist, (char *)item_list->data);
+			/* item_list is prepended to items_full_list and not the other way
+			   because when we have a large number of items say 50000, 
+			   for each iteration there will be more elements in items_full_list 
+			   and less elements in item_list */
+			
+			last_element = g_list_last (item_list);
+			if (items_full_list) {
+				last_element->next = items_full_list;
+				items_full_list->prev = last_element;
 			}
+			items_full_list = item_list;
 		}
-		g_list_free (item_list);
 		position = E_GW_CURSOR_POSITION_CURRENT;
 	}
 	e_gw_connection_destroy_cursor (m->cnc, m->container_id, cursor);
+	/* Take out only the first part in the list until the @ since it is guaranteed
+	   to be unique only until that symbol */
+
+	/*if (items_full_list) {
+		int i;
+		item_list = items_full_list;
+		
+		while (item_list->next) {
+			i = 0;
+			while (((const char *)item_list->data)[i++]!='@');
+			((char *)item_list->data)[i-1] = '\0';
+			item_list = item_list->next;
+		}
+
+		i = 0;	
+		while (((const char *)item_list->data)[i++]!='@');
+		((char *)item_list->data)[i-1] = '\0';
+	}*/
+	
+	g_print ("\nNumber of items in the folder: %d \n", g_list_length(items_full_list));
+	gw_update_all_items (m->folder, items_full_list, ex);
 
-	gw_update_all_items (m->folder, m->slist, ex);
 }
 
 static void
@@ -870,7 +942,12 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 	char *container_id = NULL;
 	char *time_string = NULL, *t_str = NULL;
 	struct _folder_update_msg *msg;
+	gboolean check_all = FALSE;
 
+	/* Sync-up the (un)read changes before getting updates,
+	so that the getFolderList will reflect the most recent changes too */
+	groupwise_sync (folder, FALSE, ex);
+	
 	if (((CamelOfflineStore *) gw_store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
 		g_warning ("In offline mode. Cannot refresh!!!\n");
 		return;
@@ -892,7 +969,7 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 	if (!camel_groupwise_store_connected (gw_store, ex)) 
 		goto end1;
 
-	if (!strcmp (folder->full_name, "Trash") || is_proxy) {
+	if (!strcmp (folder->full_name, "Trash")) {
 		status = e_gw_connection_get_items (cnc, container_id, "peek recipient distribution created delivered attachments subject status size", NULL, &list);
 		if (status != E_GW_CONNECTION_STATUS_OK) {
 			if (status ==E_GW_CONNECTION_STATUS_OTHER) {
@@ -914,57 +991,78 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 
 	time_string =  g_strdup (((CamelGroupwiseSummary *) folder->summary)->time_string);
 	t_str = g_strdup (time_string); 
+
+	
 	/*Get the New Items*/
-	status = e_gw_connection_get_quick_messages (cnc, container_id,
-			"peek id",
-			&t_str, "New", NULL, NULL, -1, &slist);
-	if (status != E_GW_CONNECTION_STATUS_OK) {
-		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Authentication failed"));
-		goto end2;
+	if (!is_proxy) {
+		status = e_gw_connection_get_quick_messages (cnc, container_id,
+				"peek id",
+				&t_str, "New", NULL, NULL, -1, &slist);
+		if (status != E_GW_CONNECTION_STATUS_OK) {
+			camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Authentication failed"));
+			goto end2;
+		}
+
+		/*
+		 * The value in t_str is the one that has to be used for the next set of calls. 
+		 * so store this value in the summary.
+		 */
+		if (summary->time_string)
+			g_free (summary->time_string);
+
+
+		summary->time_string = g_strdup (t_str);
+		g_free (t_str);	
+		t_str = NULL;
+
+		/*
+		   for ( sl = slist ; sl != NULL; sl = sl->next) 
+		   list = g_list_append (list, sl->data);*/
+
+		if (slist && g_slist_length(slist) != 0)
+			check_all = TRUE;
+
+
+		g_slist_free (slist);
+		slist = NULL;
+
+		t_str = g_strdup (time_string);
+
+		/*Get those items which have been modifed*/
+		status = e_gw_connection_get_quick_messages (cnc, container_id,
+				"peek id",
+				&t_str, "Modified", NULL, NULL, -1, &slist);
+
+		if (status != E_GW_CONNECTION_STATUS_OK) {
+			camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Authentication failed"));
+			goto end3;
+		}
+
+		/* The storing of time-stamp to summary code below should be commented if the 
+		   above commented code is uncommented */
+
+		/*	if (summary->time_string)
+			g_free (summary->time_string);
+
+			summary->time_string = g_strdup (t_str);
+
+			g_free (t_str), t_str = NULL;*/
+
+
+		for ( sl = slist ; sl != NULL; sl = sl->next) 
+			list = g_list_prepend (list, sl->data);
+
+		g_slist_free (slist);
+		slist = NULL;
+
+		if (gw_store->current_folder != folder) {
+			gw_store->current_folder = folder;
+		}
+
+		if (list) {
+			gw_update_cache (folder, list, ex, FALSE);
+		}
 	}
-
-	/*
-	 * The value in t_str is the one that has to be used for the next set of calls. 
-	 * so store this value in the summary.
-	 */
-	if (summary->time_string)
-		g_free (summary->time_string);
-	summary->time_string = g_strdup (t_str);
-	g_free (t_str);	
-	t_str = NULL;
-
-	for ( sl = slist ; sl != NULL; sl = sl->next) 
-		list = g_list_append (list, sl->data);
-
-	g_slist_free (slist);
-	slist = NULL;
-
-	t_str = g_strdup (time_string);
-
-	/*Get those items which have been modifed*/
-	status = e_gw_connection_get_quick_messages (cnc, container_id,
-			"peek id",
-			&t_str, "Modified", NULL, NULL, -1, &slist);
-	g_free (t_str), t_str = NULL;
-	if (status != E_GW_CONNECTION_STATUS_OK) {
-		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Authentication failed"));
-		goto end3;
-	}
-	
-	for ( sl = slist ; sl != NULL; sl = sl->next) 
-		list = g_list_append (list, sl->data);
-
-	g_slist_free (slist);
-	slist = NULL;
-
-	if (gw_store->current_folder != folder) {
-		gw_store->current_folder = folder;
-	}
-
-	if (list) {
-		gw_update_cache (folder, list, ex);
-	}
-	
  
 	CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
 	is_locked = FALSE;
@@ -976,16 +1074,17 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 	 * this folder, and update the summary.
 	 */
 	/*create a new session thread for the update all operation*/
-	msg = camel_session_thread_msg_new (session, &update_ops, sizeof(*msg));
-	msg->cnc = cnc;
-	msg->t_str = g_strdup (time_string);
-	msg->container_id = g_strdup (container_id);
-	msg->folder = folder;
-	camel_object_ref (folder);
-	camel_folder_freeze (folder);
-	camel_session_thread_queue (session, &msg->msg, 0);
-	/*thread creation and queueing done*/
-
+	if (check_all || is_proxy) {
+		msg = camel_session_thread_msg_new (session, &update_ops, sizeof(*msg));
+		msg->cnc = cnc;
+		msg->t_str = g_strdup (time_string);
+		msg->container_id = g_strdup (container_id);
+		msg->folder = folder;
+		camel_object_ref (folder);
+		camel_folder_freeze (folder);
+		camel_session_thread_queue (session, &msg->msg, 0);
+		/*thread creation and queueing done*/
+	}
 
 end3: 
 	g_list_foreach (list, (GFunc) g_object_unref, NULL);
@@ -1001,10 +1100,11 @@ end1:
 	return;
 }
 
-void
-gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex) 
+static void
+gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex, gboolean uid_flag) 
 {
 	CamelGroupwiseMessageInfo *mi = NULL;
+	CamelMessageInfo *pmi = NULL;
 	CamelGroupwiseStore *gw_store = CAMEL_GROUPWISE_STORE (folder->parent_store);
 	CamelGroupwiseFolder *gw_folder = CAMEL_GROUPWISE_FOLDER(folder);
 	CamelGroupwiseStorePrivate *priv = gw_store->priv;
@@ -1022,6 +1122,7 @@ gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex)
 	int total_items = g_list_length (item_list), i=0;
 	
 	/*Assert lock*/
+	CAMEL_SERVICE_ASSERT_LOCKED (gw_store, connect_lock);
 	changes = camel_folder_change_info_new ();
 	container_id = g_strdup (camel_groupwise_store_container_id_lookup (gw_store, folder->full_name));
 	if (!container_id) {
@@ -1037,7 +1138,7 @@ gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex)
 	camel_operation_start (NULL, _("Fetching summary information for new messages in %s"), folder->name);
 
 	for ( ; item_list != NULL ; item_list = g_list_next (item_list) ) {
-		EGwItem *temp_item = (EGwItem *)item_list->data;
+		EGwItem *temp_item;
 		EGwItem *item;
 		EGwItemType type = E_GW_ITEM_TYPE_UNKNOWN;
 		EGwItemOrganizer *org;
@@ -1045,20 +1146,19 @@ gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex)
 		const char *id;
 		GSList *recp_list = NULL;
 		status_flags = 0;
-		CamelStream *cache_stream;
+		CamelStream *cache_stream, *t_cache_stream;
 		CamelMimeMessage *mail_msg = NULL;
+		gboolean is_sent_folder = FALSE;
 
 		exists = FALSE;
-		id = e_gw_item_get_id (temp_item);
+		
+		if (uid_flag == FALSE) {
+			temp_item = (EGwItem *)item_list->data;
+			id = e_gw_item_get_id (temp_item);
+		} else 
+			id = (char *) item_list->data;
 
 		camel_operation_progress (NULL, (100*i)/total_items);
-		cache_stream  = camel_data_cache_get (gw_folder->cache, "cache", id, ex);
-		if (cache_stream) {
-			camel_object_unref (cache_stream);
-			cache_stream = NULL;
-			i++;
-			continue;
-		} 
 
 		status = e_gw_connection_get_item (cnc, container_id, id, "peek default distribution recipient message attachments subject notification created recipientStatus status size", &item);
 		if (status != E_GW_CONNECTION_STATUS_OK) {
@@ -1068,9 +1168,12 @@ gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex)
 
 		/************************ First populate summary *************************/
 		mi = NULL;
-		mi = (CamelGroupwiseMessageInfo *)camel_folder_summary_uid (folder->summary, id);
-		if (mi) {
+		pmi = NULL;
+		pmi = camel_folder_summary_uid (folder->summary, id);
+		if (pmi) {
 			exists = TRUE;
+			camel_message_info_ref (pmi);
+			mi = (CamelGroupwiseMessageInfo *)pmi;
 		}
 
 		if (!exists) {
@@ -1094,15 +1197,24 @@ gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex)
 		item_status = e_gw_item_get_item_status (item);
 		if (item_status & E_GW_ITEM_STAT_READ)
 			status_flags |= CAMEL_MESSAGE_SEEN;
+		else 
+			mi->info.flags &= ~CAMEL_MESSAGE_SEEN;
+
 		if (item_status & E_GW_ITEM_STAT_REPLIED)
 			status_flags |= CAMEL_MESSAGE_ANSWERED;
-		mi->info.flags |= status_flags;
+		
+		if (exists) 
+			mi->info.flags |= status_flags;
+		else 
+			mi->info.flags = status_flags;
 
 		priority = e_gw_item_get_priority (item);
 		if (priority && !(g_ascii_strcasecmp (priority,"High"))) {
 			mi->info.flags |= CAMEL_MESSAGE_FLAGGED;
 		}
 
+		mi->server_flags = mi->info.flags;
+
 		attach_list = e_gw_item_get_attach_id_list (item);
 		if (attach_list)  {
 			GSList *al = attach_list;
@@ -1119,12 +1231,17 @@ gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex)
 
 		org = e_gw_item_get_organizer (item); 
 		if (org) {
-			if (exists)
-				camel_pstring_free(mi->info.from);
-			if (org->display_name && org->display_name[0])
-				mi->info.from = camel_pstring_strdup (org->display_name);
-			else if (org->email && org->email[0])
-				mi->info.from = camel_pstring_strdup (org->email);
+			GString *str;
+			str = g_string_new ("");
+			if (org->display_name && org->display_name[0]) 
+				str = g_string_append (str, org->display_name);
+			if (org->email && org->email[0]) { 
+				g_string_append (str, "<");
+				str = g_string_append (str, org->email);
+				g_string_append (str, ">");
+			}
+			mi->info.from = camel_pstring_strdup (str->str);
+			g_string_free (str, TRUE);
 		}
 		g_string_truncate (str, 0);
 		recp_list = e_gw_item_get_recipient_list (item);
@@ -1170,18 +1287,16 @@ gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex)
 				mi->info.date_sent = mi->info.date_received = actual_time;
 			}
 		}
-
-		if (exists)
-			g_free(mi->info.uid);
-		mi->info.uid = g_strdup(e_gw_item_get_id(item));
-		if (!exists)
+		
+		if (!exists){
+			mi->info.uid = g_strdup (e_gw_item_get_id(item));
 			mi->info.size = e_gw_item_get_mail_size (item);	
-		if (!exists)
 			mi->info.subject = camel_pstring_strdup(e_gw_item_get_subject(item));
+		}
 		
 		if (exists) {
-			camel_folder_change_info_change_uid (changes, e_gw_item_get_id (item));
-			camel_message_info_free (&mi->info);
+			camel_folder_change_info_change_uid (changes, mi->info.uid);
+			camel_message_info_free (pmi);
 		} else {
 			camel_folder_summary_add (folder->summary,(CamelMessageInfo *)mi);
 			camel_folder_change_info_add_uid (changes, mi->info.uid);
@@ -1193,13 +1308,16 @@ gw_update_cache ( CamelFolder *folder, GList *list, CamelException *ex)
 			continue;
 
 		if (!strcmp (folder->full_name, "Sent Items"))
-			exists = FALSE;
+			is_sent_folder = TRUE;
 		/******************** Begine Caching ************************/
-		mail_msg = groupwise_folder_item_to_msg (folder, item, ex);
-		if (mail_msg)
-			camel_medium_set_header (CAMEL_MEDIUM (mail_msg), "X-Evolution-Source", groupwise_base_url_lookup (priv));
 		/* add to cache if its a new message*/
-		if (!exists) {
+		t_cache_stream  = camel_data_cache_get (gw_folder->cache, "cache", id, ex);
+		if (t_cache_stream && !is_sent_folder) {
+			camel_object_unref (t_cache_stream);
+			
+			mail_msg = groupwise_folder_item_to_msg (folder, item, ex);
+			if (mail_msg)
+				camel_medium_set_header (CAMEL_MEDIUM (mail_msg), "X-Evolution-Source", groupwise_base_url_lookup (priv));
 			CAMEL_GROUPWISE_FOLDER_LOCK (folder, cache_lock);
 			if ((cache_stream = camel_data_cache_add (gw_folder->cache, "cache", id, NULL))) {
 				if (camel_data_wrapper_write_to_stream ((CamelDataWrapper *) mail_msg, 	cache_stream) == -1 || camel_stream_flush (cache_stream) == -1)
@@ -1315,10 +1433,17 @@ gw_update_summary ( CamelFolder *folder, GList *list,CamelException *ex)
 
 		org = e_gw_item_get_organizer (item); 
 		if (org) {
-			if (org->display_name && org->display_name[0])
-				mi->info.from = camel_pstring_strdup (org->display_name);
-			else if (org->email && org->email[0])
-				mi->info.from = camel_pstring_strdup (org->email);
+			GString *str;
+			str = g_string_new ("");
+			if (org->display_name && org->display_name[0]) 
+				str = g_string_append (str, org->display_name);
+			if (org->email && org->email[0]) { 
+				g_string_append (str, "<");
+				str = g_string_append (str, org->email);
+				g_string_append (str, ">");
+			}
+			mi->info.from = camel_pstring_strdup (str->str);
+			g_string_free (str, TRUE);
 		}
 		g_string_truncate (str, 0);
 		recp_list = e_gw_item_get_recipient_list (item);
@@ -1592,55 +1717,55 @@ groupwise_folder_item_to_msg( CamelFolder *folder,
 	return msg;
 }
 
-static gint 
-string_cmp(gconstpointer a, gconstpointer b)
-{
-	int ret;
-	char **tmp1, **tmp2;
-	
-	tmp1 = g_strsplit ((const char *)a, "@", -1);
-	tmp2 = g_strsplit ((const char *)b, "@", -1);
-	ret = strcmp (tmp1[0], tmp2[0]);
-	g_strfreev (tmp1);
-	g_strfreev (tmp2);
-	return ret;
-}
-
 static void
-gw_update_all_items ( CamelFolder *folder, GSList *item_list, CamelException *ex) 
+gw_update_all_items ( CamelFolder *folder, GList *item_list, CamelException *ex) 
 {
 	CamelGroupwiseFolder *gw_folder = CAMEL_GROUPWISE_FOLDER (folder);
-	GPtrArray *summary = camel_folder_get_summary (folder);
+	GPtrArray *summary = NULL;
 	int index = 0;
-	GSList *item_ids = NULL, *l = NULL;
+	GList *temp;
 	CamelFolderChangeInfo *changes = NULL;
+	CamelMessageInfo *info;
 
 	changes = camel_folder_change_info_new ();
+
+	item_list = g_list_reverse (item_list);
+	
+	summary = camel_folder_get_summary (folder);
 	/*item_ids : List of ids from the summary*/
 	while (index < summary->len) {
-		CamelMessageInfo *info = g_ptr_array_index (summary, index);
-		item_ids = g_slist_append (item_ids, info->uid);
-		index ++;
-	}
-	l = item_ids;
-
-	/*item_list : List of ids from the server*/
-	for (; item_ids != NULL ; item_ids = g_slist_next (item_ids)) {
-		GSList *temp = NULL;
-
-		temp = g_slist_find_custom (item_list, (const char *)item_ids->data, (GCompareFunc) string_cmp);
+		info = g_ptr_array_index (summary, index);
+		temp = NULL; 
+		
+		if (item_list) {
+			temp = g_list_find_custom (item_list, (const char *)info->uid, (GCompareFunc) strcmp);
+		}
 		if (!temp) {
 			CAMEL_GROUPWISE_FOLDER_LOCK (folder, cache_lock);
-			camel_folder_summary_remove_uid (folder->summary, (const char *)item_ids->data);
-			camel_data_cache_remove(gw_folder->cache, "cache", (const char *)item_ids->data, ex);
-			camel_folder_change_info_remove_uid(changes, (const char *)item_ids->data);
+			camel_folder_summary_remove_uid (folder->summary, info->uid);
+			camel_data_cache_remove (gw_folder->cache, "cache", info->uid, ex);
+			camel_folder_change_info_remove_uid (changes, info->uid);
 			CAMEL_GROUPWISE_FOLDER_UNLOCK (folder, cache_lock);
-		} 
+		} else { 
+			item_list = g_list_delete_link (item_list, temp);
+		}
+		index ++;
 	}
 	camel_object_trigger_event (folder, "folder_changed", changes);
+	
+	if (item_list) {
+		CamelGroupwiseStore *gw_store = CAMEL_GROUPWISE_STORE (folder->parent_store);
+
+		CAMEL_SERVICE_LOCK (gw_store, connect_lock);
+		gw_update_cache (folder, item_list, ex, TRUE);	
+		CAMEL_SERVICE_UNLOCK (gw_store, connect_lock);
+		
+		g_list_foreach (item_list, (GFunc)g_free, NULL);	
+		g_list_free (item_list);
+	}
+	
 
 	camel_folder_free_summary (folder, summary);
-	g_slist_free (l);
 }
 
 static void
@@ -1652,7 +1777,6 @@ groupwise_append_message (CamelFolder *folder, CamelMimeMessage *message,
 	CamelGroupwiseStore *gw_store= CAMEL_GROUPWISE_STORE(folder->parent_store);
 	CamelGroupwiseStorePrivate  *priv = gw_store->priv;
 	CamelOfflineStore *offline = (CamelOfflineStore *) folder->parent_store;
-	CamelAddress *recipients;
 	EGwConnectionStatus status;
 	EGwConnection *cnc;
 	EGwItem *item;
@@ -1679,14 +1803,8 @@ groupwise_append_message (CamelFolder *folder, CamelMimeMessage *message,
 	CAMEL_SERVICE_LOCK (folder->parent_store, connect_lock);
 	/*Get the container id*/
 	container_id = camel_groupwise_store_container_id_lookup (gw_store, folder->full_name) ;
-
-	/* FIXME Separate To/CC/BCC? */
-	recipients = CAMEL_ADDRESS (camel_internet_address_new ());
-	camel_address_cat (recipients, CAMEL_ADDRESS (camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_TO)));
-	camel_address_cat (recipients, CAMEL_ADDRESS (camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_CC)));
-	camel_address_cat (recipients, CAMEL_ADDRESS (camel_mime_message_get_recipients (message, CAMEL_RECIPIENT_TYPE_BCC)));
-
-	item = camel_groupwise_util_item_from_message (cnc, message, CAMEL_ADDRESS (message->from), recipients);
+	
+	item = camel_groupwise_util_item_from_message (cnc, message, CAMEL_ADDRESS (message->from));
 	/*Set the source*/
 	if (!strcmp (folder->name, RECEIVED))
 			e_gw_item_set_source (item, "received");
@@ -1823,15 +1941,16 @@ groupwise_transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 		if (status == E_GW_CONNECTION_STATUS_OK) {
 			if (delete_originals) 
 				camel_folder_delete_message(source, uids->pdata[index]);
-			/* Refresh the destination folder, if its not refreshed already */
-			if (gw_store->current_folder != destination || 
-				camel_folder_summary_count (destination->summary) == count)
-				camel_folder_refresh_info (destination, ex);
 		} else {
 			g_warning ("Warning!! Could not move item : %s\n", (char *)uids->pdata[index]);
 		}
 		index ++;
 	}
+	/* Refresh the destination folder, if its not refreshed already */
+	if (gw_store->current_folder != destination || 
+			camel_folder_summary_count (destination->summary) == count)
+		camel_folder_refresh_info (destination, ex);
+
 	camel_folder_summary_touch (source->summary);
 	camel_folder_summary_touch (destination->summary);
 
@@ -1854,8 +1973,10 @@ groupwise_expunge (CamelFolder *folder, CamelException *ex)
 	CamelFolderChangeInfo *changes;
 	int i, max;
 	gboolean delete = FALSE;
+	GList *deleted_items, *deleted_head = NULL;
 	
-	
+
+	deleted_items = NULL;
 	cnc = cnc_lookup (priv);
 	if (!cnc)
 		return;
@@ -1882,23 +2003,60 @@ groupwise_expunge (CamelFolder *folder, CamelException *ex)
 		info = camel_folder_summary_index (folder->summary, i);
 		ginfo = (CamelGroupwiseMessageInfo *) info;
 		if (ginfo && (ginfo->info.flags & CAMEL_MESSAGE_DELETED)) {
-			const char *uid = camel_message_info_uid (info);
-			CAMEL_SERVICE_LOCK (groupwise_store, connect_lock);
-			status = e_gw_connection_remove_item (cnc, container_id, uid);
-			if (status == E_GW_CONNECTION_STATUS_OK) {
-				CAMEL_GROUPWISE_FOLDER_LOCK (folder, cache_lock);
-				camel_folder_change_info_remove_uid (changes, (char *) uid);
-				camel_folder_summary_remove (folder->summary, info);
-				camel_data_cache_remove(gw_folder->cache, "cache", uid, ex);
-				CAMEL_GROUPWISE_FOLDER_UNLOCK (folder, cache_lock);
+
+			if (deleted_items)
+				deleted_items = g_list_prepend (deleted_items, (char *)camel_message_info_uid (info));
+			else {
+				g_list_free (deleted_head);
+				deleted_head = NULL;
+				deleted_head = deleted_items = g_list_prepend (deleted_items, (char *)camel_message_info_uid (info));
+			}
+			if (g_list_length (deleted_items) == GROUPWISE_BULK_DELETE_LIMIT ) {
+				/* Read the FIXME below */
+				CAMEL_SERVICE_LOCK (groupwise_store, connect_lock);
+				status = e_gw_connection_remove_items (cnc, container_id, deleted_items);
+				CAMEL_SERVICE_UNLOCK (groupwise_store, connect_lock);
+				if (status == E_GW_CONNECTION_STATUS_OK) {
+					char *uid;
+					while (deleted_items) {
+						uid = (char *)deleted_items->data;
+						CAMEL_GROUPWISE_FOLDER_LOCK (folder, cache_lock);
+						camel_folder_change_info_remove_uid (changes, uid);
+						camel_folder_summary_remove_uid (folder->summary, uid);
+						camel_data_cache_remove(gw_folder->cache, "cache", uid, ex);
+						CAMEL_GROUPWISE_FOLDER_UNLOCK (folder, cache_lock);
+						deleted_items = g_list_next (deleted_items);
+						max -= GROUPWISE_BULK_DELETE_LIMIT;
+						i -= GROUPWISE_BULK_DELETE_LIMIT;
+					}
+				}
 				delete = TRUE;
-				i--;  max--;
 			}
-			CAMEL_SERVICE_UNLOCK (groupwise_store, connect_lock);
 		}
 		camel_message_info_free (info);
 	}
 
+	if (deleted_items) {
+		/* FIXME: Put these in a function and reuse it inside the above loop, here and in groupwise_sync*/
+		CAMEL_SERVICE_LOCK (groupwise_store, connect_lock);
+		status = e_gw_connection_remove_items (cnc, container_id, deleted_items);
+		CAMEL_SERVICE_UNLOCK (groupwise_store, connect_lock);
+		if (status == E_GW_CONNECTION_STATUS_OK) {
+			char *uid;
+			while (deleted_items) {
+				uid = (char *)deleted_items->data;
+				CAMEL_GROUPWISE_FOLDER_LOCK (folder, cache_lock);
+				camel_folder_change_info_remove_uid (changes, uid);
+				camel_folder_summary_remove_uid (folder->summary, uid);
+				camel_data_cache_remove(gw_folder->cache, "cache", uid, ex);
+				CAMEL_GROUPWISE_FOLDER_UNLOCK (folder, cache_lock);
+				deleted_items = g_list_next (deleted_items);
+			}
+		}
+		delete = TRUE;
+		g_list_free (deleted_head);
+	}
+
 	if (delete)
 		camel_object_trigger_event (CAMEL_OBJECT (folder), "folder_changed", changes);
 	
