@@ -88,6 +88,18 @@ e_name_selector_entry_realize (GtkWidget *widget)
 static void
 e_name_selector_entry_dispose (GObject *object)
 {
+	ENameSelectorEntry *name_selector_entry = E_NAME_SELECTOR_ENTRY (object);
+
+	if (name_selector_entry->entry_completion) {
+		g_object_unref (name_selector_entry->entry_completion);
+		name_selector_entry->entry_completion = NULL;
+	}
+
+	if (name_selector_entry->destination_store) {
+		g_object_unref (name_selector_entry->destination_store);
+		name_selector_entry->destination_store = NULL;
+	}
+
 	if (G_OBJECT_CLASS (e_name_selector_entry_parent_class)->dispose)
 		G_OBJECT_CLASS (e_name_selector_entry_parent_class)->dispose (object);
 }
@@ -1193,6 +1205,23 @@ user_delete_text (ENameSelectorEntry *name_selector_entry, gint start_pos, gint
 	gtk_editable_delete_text (GTK_EDITABLE (name_selector_entry),
 				  start_pos, end_pos);
 	
+	/*If the user is deleting a '"' new destinations have to be created for ',' between the quoted text
+	 Like "fd,ty,uy" is a one entity, but if you remove the quotes it has to be broken doan into 3 seperate
+	 addresses.
+	*/
+
+	if (str_b_context [1] == '"') {
+		const gchar *p;
+		gint i;
+		p = text + end_pos;
+		for (p = text + (end_pos-1), i = end_pos - 1; *p && *p != '"' ; p = g_utf8_next_char (p), i++) {
+			gunichar c = g_utf8_get_char (p);
+			if(c == ',') {
+				insert_destination_at_position (name_selector_entry, i+1);
+			}
+		}
+		
+	}
 
 	/* Let model know about changes */
 	text = gtk_entry_get_text (GTK_ENTRY (name_selector_entry));
@@ -1698,6 +1727,39 @@ find_book_by_contact (GList *books, const gchar *contact_uid)
 static void
 editor_closed_cb (GtkObject *editor, gpointer data)
 {
+	EContact *contact;
+	gchar *contact_uid;
+	EDestination *destination;
+	GList *books;
+	EBook *book;
+	gboolean result;
+	gint email_num;
+	ENameSelectorEntry *name_selector_entry = E_NAME_SELECTOR_ENTRY (data);
+	
+	destination = name_selector_entry->popup_destination;
+	contact = e_destination_get_contact (destination);
+	if (!contact)
+		return;
+	contact_uid = e_contact_get (contact, E_CONTACT_UID);
+	if (!contact_uid)
+		return;
+
+	if (name_selector_entry->contact_store) {
+		books = e_contact_store_get_books (name_selector_entry->contact_store);
+		book = find_book_by_contact (books, contact_uid);
+		g_list_free (books);
+	} else {
+		book = NULL;
+	}
+	if (!book)
+		return;
+
+	result = e_book_get_contact(book, contact_uid, &contact, NULL);
+	email_num = e_destination_get_email_num(destination);
+	e_destination_set_contact (destination, contact, email_num);
+
+	g_free (contact_uid);
+	g_object_unref (contact);
 	g_object_unref (editor);
 }
 
@@ -1705,6 +1767,7 @@ static void
 popup_activate_inline_expand (ENameSelectorEntry *name_selector_entry, GtkWidget *menu_item)
 {
 	const char *email_list, *text;
+	gchar *sanitized_text;
 	EDestination *destination = name_selector_entry->popup_destination;
 	int position, start, end;
 
@@ -1718,8 +1781,9 @@ popup_activate_inline_expand (ENameSelectorEntry *name_selector_entry, GtkWidget
 
 	gtk_editable_delete_text (GTK_EDITABLE (name_selector_entry), start, end);
 
-	text = sanitize_string (e_destination_get_textrep (destination, FALSE));
-	gtk_editable_insert_text (GTK_EDITABLE (name_selector_entry), email_list, -1, &start);
+	sanitized_text = sanitize_string (email_list);
+	gtk_editable_insert_text (GTK_EDITABLE (name_selector_entry), sanitized_text, -1, &start);
+	g_free (sanitized_text);
 
 	g_signal_handlers_unblock_by_func (name_selector_entry, user_delete_text, name_selector_entry);
 
@@ -1769,7 +1833,7 @@ popup_activate_contact (ENameSelectorEntry *name_selector_entry, GtkWidget *menu
 
 		contact_list_editor = (*name_selector_entry->contact_list_editor_func) (book, contact, FALSE, TRUE);
 		g_signal_connect (contact_list_editor, "editor_closed",
-				  G_CALLBACK (editor_closed_cb), NULL);
+				  G_CALLBACK (editor_closed_cb), name_selector_entry);
 	} else {
 		GtkWidget *contact_editor;
 
@@ -1778,7 +1842,7 @@ popup_activate_contact (ENameSelectorEntry *name_selector_entry, GtkWidget *menu
 
 		contact_editor = (*name_selector_entry->contact_editor_func) (book, contact, FALSE, TRUE);
 		g_signal_connect (contact_editor, "editor_closed",
-				  G_CALLBACK (editor_closed_cb), NULL);
+				  G_CALLBACK (editor_closed_cb), name_selector_entry);
 	}
 }
 
